==> nats.c_3.7.0.orig.tar.gz: nats.c-3.7.0/doc/html/search/groups_b.js <==
var searchData=
[
  ['statistics_0',['Statistics',['../group__stats_group.html',1,'']]],
  ['status_1',['status',['../group__kv_status.html',1,'KeyValue store status'],['../group__status_group.html',1,'Status']]],
  ['store_2',['KeyValue store',['../group__kv_group.html',1,'']]],
  ['store_20entries_3',['KeyValue store entries',['../group__kv_entry.html',1,'']]],
  ['store_20management_4',['KeyValue store management',['../group__kv_group_mgt.html',1,'']]],
  ['store_20status_5',['KeyValue store status',['../group__kv_status.html',1,'']]],
  ['store_20watcher_6',['KeyValue store watcher',['../group__kv_watcher.html',1,'']]],
  ['streaming_20connection_7',['Streaming Connection',['../group__stan_conn_group.html',1,'']]],
  ['streaming_20connection_20options_8',['Streaming Connection Options',['../group__stan_conn_opts_group.html',1,'']]],
  ['streaming_20message_9',['Streaming Message',['../group__stan_msg_group.html',1,'']]],
  ['streaming_20subscription_10',['Streaming Subscription',['../group__stan_sub_group.html',1,'']]],
  ['streaming_20subscription_20options_11',['Streaming Subscription Options',['../group__stan_sub_opts_group.html',1,'']]],
  ['structs_12',['Public structs',['../group__micro_structs.html',1,'']]],
  ['subscribing_13',['subscribing',['../group__stan_conn_sub_group.html',1,'Subscribing'],['../group__js_sub_group.html',1,'Subscribing'],['../group__conn_sub_group.html',1,'Subscribing']]],
  ['subscription_14',['subscription',['../group__stan_sub_group.html',1,'Streaming Subscription'],['../group__sub_group.html',1,'Subscription']]],
  ['subscription_20options_15',['Streaming Subscription Options',['../group__stan_sub_opts_group.html',1,'']]]
];

==> nats.c_3.10.1.orig.tar.gz: nats.c-3.10.1/doc/html/search/groups_b.js <==
var searchData=
[
  ['statistics_0',['Statistics',['../group__stats_group.html',1,'']]],
  ['status_1',['status',['../group__kv_status.html',1,'KeyValue store status'],['../group__status_group.html',1,'Status']]],
  ['store_2',['KeyValue store',['../group__kv_group.html',1,'']]],
  ['store_20entries_3',['KeyValue store entries',['../group__kv_entry.html',1,'']]],
  ['store_20management_4',['KeyValue store management',['../group__kv_group_mgt.html',1,'']]],
  ['store_20status_5',['KeyValue store status',['../group__kv_status.html',1,'']]],
  ['store_20watcher_6',['KeyValue store watcher',['../group__kv_watcher.html',1,'']]],
  ['streaming_20connection_7',['Streaming Connection',['../group__stan_conn_group.html',1,'']]],
  ['streaming_20connection_20options_8',['Streaming Connection Options',['../group__stan_conn_opts_group.html',1,'']]],
  ['streaming_20message_9',['Streaming Message',['../group__stan_msg_group.html',1,'']]],
  ['streaming_20subscription_10',['Streaming Subscription',['../group__stan_sub_group.html',1,'']]],
  ['streaming_20subscription_20options_11',['Streaming Subscription Options',['../group__stan_sub_opts_group.html',1,'']]],
  ['structs_12',['Public structs',['../group__micro_structs.html',1,'']]],
  ['subscribing_13',['subscribing',['../group__js_sub_group.html',1,'Subscribing'],['../group__stan_conn_sub_group.html',1,'Subscribing'],['../group__conn_sub_group.html',1,'Subscribing']]],
  ['subscription_14',['subscription',['../group__stan_sub_group.html',1,'Streaming Subscription'],['../group__sub_group.html',1,'Subscription']]],
  ['subscription_20options_15',['Streaming Subscription Options',['../group__stan_sub_opts_group.html',1,'']]]
];
